Read in Measurement Data
==============================

This example shows how DMT can read-in large amounts of measurement data and store the results in a DutLib object. 

The code
--------
.. literalinclude:: read_in_measurement_data.py

